@@ -1,7 +1,6 @@
 package Device::Firewall::PaloAlto::Errors;
-$Device::Firewall::PaloAlto::Errors::VERSION = '0.1.4_1'; # TRIAL
-
-$Device::Firewall::PaloAlto::Errors::VERSION = '0.1.41';use strict;
+$Device::Firewall::PaloAlto::Errors::VERSION = '0.1.5';
+use strict;
 use warnings;
 use 5.010;
 
@@ -20,6 +19,8 @@ use Carp;
 
 sub ERROR {
     my ($errstring, $errno) = @_;
+
+    $errno //= 0;
     
     # Are we in a one liner? If so, we croak out straight away
     my ($sub, $file, $inc);
@@ -46,7 +47,7 @@ Device::Firewall::PaloAlto::Errors - Parent class for errors.
 
 =head1 VERSION
 
-version 0.1.4_1
+version 0.1.5
 
 =head1 SYNOPSIS
 
