@@ -1,7 +1,6 @@
 package Device::Firewall::PaloAlto::JSON;
-$Device::Firewall::PaloAlto::JSON::VERSION = '0.1.4_1'; # TRIAL
-
-$Device::Firewall::PaloAlto::JSON::VERSION = '0.1.41';use strict;
+$Device::Firewall::PaloAlto::JSON::VERSION = '0.1.5';
+use strict;
 use warnings;
 use 5.010;
 
@@ -56,7 +55,7 @@ Device::Firewall::PaloAlto::JSON - JSON parent class for Device::Firewall::PaloA
 
 =head1 VERSION
 
-version 0.1.4_1
+version 0.1.5
 
 =head1 SYNOPSIS
 
