@@ -1,7 +1,6 @@
 package Device::Firewall::PaloAlto::Op;
-$Device::Firewall::PaloAlto::Op::VERSION = '0.1.4_1'; # TRIAL
+$Device::Firewall::PaloAlto::Op::VERSION = '0.1.5';
 
-$Device::Firewall::PaloAlto::Op::VERSION = '0.1.41';
 use strict;
 use warnings;
 use 5.010;
@@ -12,6 +11,7 @@ use Device::Firewall::PaloAlto::Op::ARPTable;
 use Device::Firewall::PaloAlto::Op::VirtualRouter;
 use Device::Firewall::PaloAlto::Op::Tunnels;
 use Device::Firewall::PaloAlto::Op::GlobalCounters;
+use Device::Firewall::PaloAlto::Op::IPUserMaps;
 
 use XML::LibXML;
 
@@ -88,6 +88,14 @@ sub global_counters {
 
 
 
+sub ip_user_mapping {
+    my $self = shift;
+
+    return Device::Firewall::PaloAlto::Op::IPUserMaps->_new( $self->_send_op_cmd('show user ip-user-mapping all') );
+}
+
+
+
 sub _send_op_cmd {
     my $self = shift;
     my ($cmd, $var) = @_;
@@ -152,7 +160,7 @@ Device::Firewall::PaloAlto::Op - Operations module for Palo Alto firewalls
 
 =head1 VERSION
 
-version 0.1.4_1
+version 0.1.5
 
 =head1 SYNOPSIS
 
@@ -205,6 +213,10 @@ Returns a L<Device::Firewall::PaloAlto::Op::Tunnels> object representing the cur
 
 Returns a L<Device::Firewall::PaloAlto::Op::GlobalCounters> object representing the global counters.
 
+=head2 ip_user_mapping
+
+Returns IP to user mappings
+
 =head1 AUTHOR
 
 Greg Foletta <greg@foletta.org>
