@@ -1,7 +1,6 @@
 package Device::Firewall::PaloAlto::Op::ARPEntry;
-$Device::Firewall::PaloAlto::Op::ARPEntry::VERSION = '0.1.4_1'; # TRIAL
-
-$Device::Firewall::PaloAlto::Op::ARPEntry::VERSION = '0.1.41';use strict;
+$Device::Firewall::PaloAlto::Op::ARPEntry::VERSION = '0.1.5';
+use strict;
 use warnings;
 use 5.010;
 
@@ -45,7 +44,7 @@ Device::Firewall::PaloAlto::Op::ARPEntry - Palo Alto firewall ARP entry
 
 =head1 VERSION
 
-version 0.1.4_1
+version 0.1.5
 
 =head1 SYNOPSIS
 
