@@ -1,7 +1,6 @@
 package Device::Firewall::PaloAlto::Op::GlobalCounters;
-$Device::Firewall::PaloAlto::Op::GlobalCounters::VERSION = '0.1.4_1'; # TRIAL
-
-$Device::Firewall::PaloAlto::Op::GlobalCounters::VERSION = '0.1.41';use strict;
+$Device::Firewall::PaloAlto::Op::GlobalCounters::VERSION = '0.1.5';
+use strict;
 use warnings;
 use 5.010;
 
@@ -49,7 +48,7 @@ Device::Firewall::PaloAlto::Op::GlobalCounters - Palo Alto firewall global syste
 
 =head1 VERSION
 
-version 0.1.4_1
+version 0.1.5
 
 =head1 SYNOPSIS
 
