@@ -1,7 +1,6 @@
 package Device::Firewall::PaloAlto::Op::Interface;
-$Device::Firewall::PaloAlto::Op::Interface::VERSION = '0.1.4_1'; # TRIAL
-
-$Device::Firewall::PaloAlto::Op::Interface::VERSION = '0.1.41';use strict;
+$Device::Firewall::PaloAlto::Op::Interface::VERSION = '0.1.5';
+use strict;
 use warnings;
 use 5.010;
 
@@ -41,7 +40,7 @@ Device::Firewall::PaloAlto::Op::Interface - Palo Alto firewall interface
 
 =head1 VERSION
 
-version 0.1.4_1
+version 0.1.5
 
 =head1 SYNOPSIS
 
