@@ -1,7 +1,6 @@
 package Device::Firewall::PaloAlto::Op::Route;
-$Device::Firewall::PaloAlto::Op::Route::VERSION = '0.1.4_1'; # TRIAL
-
-$Device::Firewall::PaloAlto::Op::Route::VERSION = '0.1.41';use strict;
+$Device::Firewall::PaloAlto::Op::Route::VERSION = '0.1.5';
+use strict;
 use warnings;
 use 5.010;
 
@@ -97,7 +96,7 @@ Device::Firewall::PaloAlto::Op::Route - Palto Alto firewall route
 
 =head1 VERSION
 
-version 0.1.4_1
+version 0.1.5
 
 =head1 SYNOPSIS
 
