@@ -1,7 +1,6 @@
 package Device::Firewall::PaloAlto::Op::Tunnels;
-$Device::Firewall::PaloAlto::Op::Tunnels::VERSION = '0.1.4_1'; # TRIAL
-
-$Device::Firewall::PaloAlto::Op::Tunnels::VERSION = '0.1.41';use strict;
+$Device::Firewall::PaloAlto::Op::Tunnels::VERSION = '0.1.5';
+use strict;
 use warnings;
 use 5.010;
 
@@ -60,7 +59,7 @@ Device::Firewall::PaloAlto::Op::Tunnels - Palo Alto IPSEC security associations
 
 =head1 VERSION
 
-version 0.1.4_1
+version 0.1.5
 
 =head1 SYNOPSIS
 
