@@ -1,7 +1,6 @@
 package Device::Firewall::PaloAlto::Op::VirtualRouter;
-$Device::Firewall::PaloAlto::Op::VirtualRouter::VERSION = '0.1.4_1'; # TRIAL
-
-$Device::Firewall::PaloAlto::Op::VirtualRouter::VERSION = '0.1.41';use strict;
+$Device::Firewall::PaloAlto::Op::VirtualRouter::VERSION = '0.1.5';
+use strict;
 use warnings;
 use 5.010;
 
@@ -79,7 +78,7 @@ Device::Firewall::PaloAlto::Op::VirtualRouter - new module
 
 =head1 VERSION
 
-version 0.1.4_1
+version 0.1.5
 
 =head1 SYNOPSIS
 
